@@ -28,7 +28,7 @@ S3WrapperGenerator <- function(R6Method, self = "x", dots = TRUE) {
   }
   if (!is.expression(R6Method) ||
       R6Method[[1L]][[2L]][[3L]] != "public_methods" ||
-      !testClass(eval(R6Method[[1L]][[2L]][[2L]]), "R6ClassGenerator")) {
+      !is.R6Class(eval(R6Method[[1L]][[2L]][[2L]]))) {
     stop(
       '"R6Method" must contain a public method of an "R6ClassGenerator".',
       call. = FALSE
@@ -413,10 +413,9 @@ cols <- function(x, ...) {
 #'   class} `".numerary"` matches the [`integer`] and [`numeric`] classes.
 #' @param pattern An optional character string passed on to the `pattern`
 #'   argument of [`grep`].
-#' @param mode An optional character vector matched to each column's [`mode`]
-#'   vector.
+#' @param mode An optional character vector matched to each column's [`mode`].
 #' @param typeof An optional character vector matched to each column's
-#'   [`typeof`] vector.
+#'   [`typeof`].
 #' @param \dots Further arguments passed on to [`grep`]. The `value` argument is
 #'   rejected.
 #' @inheritParams aggregate.DTSg
